AmplitudeEngagementView class

A SemanticsTag that provides an explicit, stable identifier for element targeting. When present on a SemanticsNode, this identifier takes precedence over the node's accessibility label.

Usage:

Semantics(
  tagForChildren: const AmplitudeEngagementView('my-button'),
  child: ElevatedButton(...),
)
Inheritance

Constructors

AmplitudeEngagementView(String identifier)
Initialize with the given identifier.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
identifier String
The identifier used to locate a view element for targeting content.
final
name String
A human-readable name for this tag used for debugging.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited