AmplitudeInitOptions class

Constructors

AmplitudeInitOptions({AmplitudeServerZone serverZone = AmplitudeServerZone.us, String? serverUrl, String? cdnUrl, String? mediaUrl, String? locale, AmplitudeLogLevel logLevel = AmplitudeLogLevel.warn, int? autoRefreshInterval})
AmplitudeInitOptions.fromMap(Map<String, dynamic> map)
factory

Properties

autoRefreshInterval int?
Auto-refresh interval in seconds. If not specified, 0, or negative, auto-refresh is disabled. Must be >= 60 seconds if enabled. Applies automatically on boot.
final
cdnUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
locale String?
final
logLevel AmplitudeLogLevel
final
mediaUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverUrl String?
final
serverZone AmplitudeServerZone
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited