GuideOrSurvey class

Constructors

GuideOrSurvey({required int id, required String title, required String status, required int step})
GuideOrSurvey.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
step → int
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited